#This file is part of Tryton.  The COPYRIGHT file at the top level of this
#repository contains the full copyright notices and license terms.

from location import *
from shipment import *
from move import *
from product import *
from inventory import *
from configuration import *
